@@ -98,7 +98,7 @@ int wantconst;
 int saveanz;
 int oldnumcopies;
 double brightness;
-double gamma;
+double ggamma;
 unsigned int cppvalue,lpivalue,cpivalue;
 unsigned int topmargin, bottommargin, leftmargin, rightmargin;
 int MediaSizeSelected, MediaTypeSelected, MediaSourceSelected;
@@ -118,19 +118,19 @@ int PPDopen;
 char *PPDfilename;
 int conflict_active;
 int nox;
-
 int num_commandline_opts;
 cups_option_t *commandline_opts;
-
 char nupLayout[5];
 char borderType[13];
-
+#if GTK_MAJOR_VERSION != 1
+int mainWindowHeight, mainWindowWidth, mainWindowX, mainWindowY, wantSaveSizePos;
+#endif
 GtkWidget *dialog;
 
 int main(int argc,char *argv[])
 {
 	GtkWidget *mainVBox = NULL,*waitLabel = NULL;
-        GtkWidget *buttonBox,*buttonPrint,*buttonAbbruch,*buttonReset,*buttonSave;
+	GtkWidget *buttonBox, *buttonPrint,*buttonAbbruch,*buttonReset,*buttonSave;
 	int i1;
 	int calledGtkLP;
 	int calledLpr;
@@ -140,6 +140,16 @@ int main(int argc,char *argv[])
 	char *z1;
 	char tmpenv[MAX_SERVER_NAME+13];
 
+#if GTK_MAJOR_VERSION != 1
+	progressBar=(GtkWidget *)NULL;
+
+	mainWindowHeight=0; 
+	mainWindowWidth=0;
+	mainWindowX=0;
+	mainWindowY=0;
+	wantSaveSizePos=0;
+#endif
+
 	dialog=(GtkWidget *)NULL;
 
 	JobName[0]=(unsigned char)NULL;
@@ -223,7 +233,6 @@ int main(int argc,char *argv[])
 
 	/*--- GUI creation ---*/
 	if(nox == 0) {
-		/*gtk_set_locale();*/
 		setlocale(LC_ALL, "");
 		gtk_init(&argc, &argv);
 
@@ -235,7 +244,6 @@ int main(int argc,char *argv[])
 		/* HauptFenster */
 		mainWindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 		gtk_window_set_title(GTK_WINDOW(mainWindow),PROGNAME);
-		gtk_window_set_policy(GTK_WINDOW(mainWindow),FALSE, FALSE, TRUE);
 		gtk_window_set_position(GTK_WINDOW(mainWindow),GTK_WIN_POS_CENTER);
 		gtk_widget_set_usize(mainWindow,WAIT_WIN_SIZE,-1);
 		gtk_signal_connect (GTK_OBJECT (mainWindow), "delete_event",GTK_SIGNAL_FUNC (destroy), NULL);
@@ -253,6 +261,15 @@ int main(int argc,char *argv[])
 		gtk_box_pack_start(GTK_BOX(mainVBox), waitLabel, TRUE, TRUE, 0);
 		gtk_widget_show(waitLabel);
 
+#if GTK_MAJOR_VERSION != 1
+		progressBar=gtk_progress_bar_new();
+		gtk_box_pack_start(GTK_BOX(mainVBox), progressBar, TRUE, TRUE, 0);
+		gtk_widget_show(progressBar);
+#endif
+
+		while (gtk_events_pending())
+			gtk_main_iteration();
+
 	}
 
 	i1=getopt(argc,argv,ProgOpts);
@@ -491,8 +508,12 @@ int main(int argc,char *argv[])
 		}
 		i1=getopt(argc,argv,ProgOpts);
 	}
+#if GTK_MAJOR_VERSION != 1
+	if(progressBar != (GtkWidget *)NULL)
+		gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressBar),0.025);
+#endif
 	filesToPrintAnz=0;
-       	if (optind < argc)
+    		if (optind < argc)
         {
                 while (optind < argc)
 		{
@@ -510,6 +531,10 @@ int main(int argc,char *argv[])
         }
 	if(filesToPrintAnz > 0)
 		ignore_stdin=1;
+#if GTK_MAJOR_VERSION != 1
+	if(progressBar != (GtkWidget *)NULL)
+		gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressBar),0.05);
+#endif
 
 	if(DEBUG)
 	{
@@ -575,6 +600,11 @@ int main(int argc,char *argv[])
 	}
 	cupsLanguage=cupsLangDefault();
 
+#if GTK_MAJOR_VERSION != 1
+	if(progressBar != (GtkWidget *)NULL)
+		gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressBar),0.075);
+#endif
+
 	/* Setting Username */
 	cupsSetUser((const char *)UserName);
 	if(DEBUG)
@@ -607,7 +637,7 @@ int main(int argc,char *argv[])
                 printf("Default-Printer(1): %s\n",DEF_PRN);
 
 	getPrinters(0);
-	
+
 	if(DEBUG)
 		printf("Default-Printer(2): %s\n",DEF_PRN);
 
@@ -634,21 +664,21 @@ int main(int argc,char *argv[])
 		tabs = gtk_notebook_new();
 		gtk_box_pack_start(GTK_BOX(mainVBox), tabs, TRUE, TRUE, 0);
 		gtk_notebook_set_tab_pos(GTK_NOTEBOOK(tabs), GTK_POS_TOP );
-		gtk_widget_show(tabs);
+		//gtk_widget_show(tabs);
 
 		/* Buttons basteln */
-		buttonBox=gtk_hbox_new(FALSE, BUTTON_SPACING_H);
-		gtk_box_pack_end(GTK_BOX(mainVBox), buttonBox, TRUE, TRUE, 0);
-	
+		buttonBox=gtk_hbox_new(TRUE, BUTTON_SPACING_H);
+		gtk_box_pack_end(GTK_BOX(mainVBox), buttonBox, FALSE, FALSE, 0);
+
 #if GTK_MAJOR_VERSION != 1
-			buttonPrint = gtk_button_new_from_stock(GTK_STOCK_PRINT);
+      buttonPrint = gtk_button_new_from_stock(GTK_STOCK_PRINT);
 #else
-			buttonPrint = gtk_button_new_with_label (str2str(_("Print")));
+      buttonPrint = gtk_button_new_with_label (str2str(_("Print")));
 #endif
-		button_pad(buttonPrint);
-		gtk_signal_connect (GTK_OBJECT (buttonPrint), "clicked",GTK_SIGNAL_FUNC (PrintFunc), NULL);
-		gtk_box_pack_start(GTK_BOX(buttonBox), buttonPrint, TRUE, TRUE, 0);
-		gtk_widget_show (buttonPrint);
+    button_pad(buttonPrint);
+    gtk_signal_connect (GTK_OBJECT (buttonPrint), "clicked",GTK_SIGNAL_FUNC (PrintFunc), NULL);
+    gtk_box_pack_start(GTK_BOX(buttonBox), buttonPrint, FALSE, TRUE, 0);
+    gtk_widget_show (buttonPrint);
 
 #if GTK_MAJOR_VERSION != 1
 		buttonReset = gtk_button_new_from_stock(GTK_STOCK_REVERT_TO_SAVED);
@@ -657,7 +687,7 @@ int main(int argc,char *argv[])
 #endif
 		button_pad(buttonReset);
 		gtk_signal_connect (GTK_OBJECT (buttonReset), "clicked",GTK_SIGNAL_FUNC (ResetFunc), NULL);
-		gtk_box_pack_start(GTK_BOX(buttonBox), buttonReset, TRUE, TRUE, 0);
+		gtk_box_pack_start(GTK_BOX(buttonBox), buttonReset, FALSE, TRUE, 0);
 		gtk_widget_show (buttonReset);
 
 #if GTK_MAJOR_VERSION != 1
@@ -667,24 +697,44 @@ int main(int argc,char *argv[])
 #endif
 		button_pad(buttonSave);
 		gtk_signal_connect (GTK_OBJECT (buttonSave), "clicked",GTK_SIGNAL_FUNC (instWin), NULL);
-		gtk_box_pack_start(GTK_BOX(buttonBox), buttonSave, TRUE, TRUE, 0);
+		gtk_box_pack_start(GTK_BOX(buttonBox), buttonSave, FALSE, TRUE, 0);
 		gtk_widget_show (buttonSave);
 
 #if GTK_MAJOR_VERSION != 1
-		buttonAbbruch = gtk_button_new_from_stock(GTK_STOCK_QUIT);
+    buttonAbbruch = gtk_button_new_from_stock(GTK_STOCK_QUIT);
 #else
-		buttonAbbruch = gtk_button_new_with_label (str2str(_("Close")));
+    buttonAbbruch = gtk_button_new_with_label (str2str(_("Close")));
+#endif
+    button_pad(buttonAbbruch);
+    gtk_signal_connect (GTK_OBJECT (buttonAbbruch), "clicked",GTK_SIGNAL_FUNC (AbbruchFunc), NULL);
+    gtk_box_pack_start(GTK_BOX(buttonBox), buttonAbbruch, FALSE, TRUE, 0);
+    gtk_widget_show (buttonAbbruch);
+
+#if GTK_MAJOR_VERSION != 1
+		if(progressBar != (GtkWidget *)NULL) {
+			gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressBar),0.95);
+			while (gtk_events_pending())
+				gtk_main_iteration();
+		}
 #endif
-		button_pad(buttonAbbruch);
-		gtk_signal_connect (GTK_OBJECT (buttonAbbruch), "clicked",GTK_SIGNAL_FUNC (AbbruchFunc), NULL);
-		gtk_box_pack_start(GTK_BOX(buttonBox), buttonAbbruch, TRUE, TRUE, 0);
-		gtk_widget_show (buttonAbbruch);
 
 		/* Tabs basteln */
 		CreateWidgets();
 
+#if GTK_MAJOR_VERSION != 1
+		if(progressBar != (GtkWidget *)NULL) {
+			gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressBar),0.99);
+			while (gtk_events_pending())
+				gtk_main_iteration();
+		}
+#endif
+
 		/* Fenster anzeigen */
+		gtk_widget_hide(mainWindow);
 		gtk_widget_hide(waitLabel);
+#if GTK_MAJOR_VERSION != 1
+		gtk_widget_hide(progressBar);
+#endif 
 		ShowWidgets();
 		if(DEBUG)
 			printf("Switching to Tab %i\n",tabtoopen);
@@ -697,6 +747,25 @@ int main(int argc,char *argv[])
 
 		gtk_widget_show(buttonBox);
 
+#if GTK_MAJOR_VERSION != 1
+		/* Restore Position */
+		if(nox == 0) {
+ 	   if(wantSaveSizePos == 1) {
+  	    if(mainWindowHeight > 0 && mainWindowWidth > 0) {
+				
+    	    gtk_widget_set_uposition(GTK_WIDGET(mainWindow), mainWindowX, mainWindowY);
+					while (gtk_events_pending())
+						gtk_main_iteration();
+	        gtk_window_resize(GTK_WINDOW(mainWindow), mainWindowWidth, mainWindowHeight);
+					while (gtk_events_pending())
+						gtk_main_iteration();
+      	}
+ 	   }
+		}
+#endif
+		if(nox == 0) 
+			gtk_widget_show(mainWindow);
+
 		if(GTK_IS_WIDGET (dialog) == 1) {		/* Error Windows back to foreground */
 			gtk_widget_hide(dialog);
 			gtk_window_set_transient_for(GTK_WINDOW(dialog),GTK_WINDOW(mainWindow));
