@@ -230,7 +230,9 @@ void getOptions(char *printername,int which)
 	char *instance;
 	cups_option_t *option;
 	char *z1;
-
+#if GTK_MAJOR_VERSION != 1
+	int screenHeight, screenWidth;
+#endif
 	num_printer=0;
 	all_printer=NULL;
 	act_printer=NULL;
@@ -317,7 +319,7 @@ void getOptions(char *printername,int which)
 								mirroroutput=0;
                 sheetsType=1;
                 brightness=100;
-                gamma=1000;
+                ggamma=1000;
                 cpivalue=10;
                 lpivalue=6;
                 cppvalue=1;
@@ -497,7 +499,7 @@ void getOptions(char *printername,int which)
 			brightness=atof(cupsGetOption("brightness",act_printer->num_options,act_printer->options));
 
 		if(cupsGetOption("gamma",act_printer->num_options,act_printer->options) != (char)NULL)
-			gamma=atof(cupsGetOption("gamma",act_printer->num_options,act_printer->options));
+			ggamma=atof(cupsGetOption("gamma",act_printer->num_options,act_printer->options));
 
 		if(cupsGetOption("cpi",act_printer->num_options,act_printer->options) != (char)NULL)
 			cpivalue=(unsigned)atol(cupsGetOption("cpi",act_printer->num_options,act_printer->options));
@@ -713,6 +715,13 @@ void getOptions(char *printername,int which)
 		strncpy(HELPURL,DEF_HELP_HOME,(size_t)MAXPATH);
 		GTKLPQCOM[0]=(char)NULL;
 		wantconst=0;
+#if GTK_MAJOR_VERSION != 1
+		mainWindowHeight=0; 
+		mainWindowWidth=0;
+		mainWindowX=0;
+		mainWindowY=0;
+		wantSaveSizePos=0;
+#endif
 
 
 	        if(DEBUG)
@@ -749,13 +758,14 @@ void getOptions(char *printername,int which)
                 	        printf("Loading global defaults\n");
 	                tmp[0]=(unsigned char)NULL; 
         	        freadline(file,tmp,MAXLINE);	/* last Printer */
+
+						fscanf(file,"%i\n",&rememberprinter);
 						if((rememberprinter == 1) && DEF_PRN[0] == (unsigned char)NULL)
 						{
 							if(DEBUG)
 								printf("set printer to remembered: %s\n",tmp);
 							strncpy(DEF_PRN,tmp,(size_t)DEF_PRN_LEN);
 						}
-	       		fscanf(file,"%i\n",&rememberprinter);
 						fscanf(file,"%i\n",&remembertab);
 						fscanf(file,"%i\n",&tabtoopen);
 						if(remembertab == 0)
@@ -775,6 +785,34 @@ void getOptions(char *printername,int which)
 			freadline(file,tmp,MAXLINE);
 			strncpy(GTKLPQCOM,tmp,(size_t)MAXPATH);
 			fscanf(file,"%i\n",&wantconst);
+#if GTK_MAJOR_VERSION != 1
+			if(fscanf(file,"%i %i %i %i %i\n",&wantSaveSizePos, &mainWindowX, &mainWindowY, &mainWindowWidth, &mainWindowHeight) == EOF) {	/* Old style conf */
+				wantSaveSizePos=0;
+				mainWindowHeight=0;
+				mainWindowWidth=0;
+				mainWindowX=0;
+				mainWindowY=0;
+			} else {
+				/* validate Size and Pos settings, ignore on too small screens */
+				if(nox == 0) {
+					screenHeight=gdk_screen_height();
+					screenWidth=gdk_screen_width();
+
+					if(mainWindowX < 0)
+						mainWindowX=0;
+					if(mainWindowY < 0)
+						mainWindowY=0;
+
+					if(mainWindowX+mainWindowWidth < WINDOWINSCREENBORDER || mainWindowY+mainWindowHeight < WINDOWINSCREENBORDER || screenWidth-mainWindowX < WINDOWINSCREENBORDER || screenHeight-mainWindowY < WINDOWINSCREENBORDER) {
+						mainWindowHeight=0;
+						mainWindowWidth=0;
+						mainWindowX=0;
+						mainWindowY=0;
+					}
+				}
+
+			}
+#endif
         	        fclose(file);
 	        }
 	}
@@ -867,7 +905,7 @@ int addAllOptions(cups_option_t **optionsptr, int num_options) {
 	} else {
 		snprintf(tmp,(size_t)MAXOPTLEN,"%.0f",brightness);
 		num_options=cupsAddOption("brightness",tmp,num_options,optionsptr);
-		snprintf(tmp,(size_t)MAXOPTLEN,"%.0f",gamma);
+		snprintf(tmp,(size_t)MAXOPTLEN,"%.0f",ggamma);
 		num_options=cupsAddOption("gamma",tmp,num_options,optionsptr);
 	}
 
@@ -1106,7 +1144,6 @@ int saveOptions(char *printername, int onlyglobal)
 	int newinstance = 0;
 	char tmp[MAXOPTLEN+1];
 
-
 	if(nox == 1)
 		return(0);
 
@@ -1293,6 +1330,14 @@ int saveOptions(char *printername, int onlyglobal)
 	fprintf(file,"%s\n",HELPURL);
 	fprintf(file,"%s\n",GTKLPQCOM);
 	fprintf(file,"%i\n",wantconst);
+
+#if GTK_MAJOR_VERSION != 1
+	/* save window state if wished */
+	gtk_window_get_position(GTK_WINDOW(mainWindow),&mainWindowX,&mainWindowY);
+	gtk_window_get_size(GTK_WINDOW(mainWindow),&mainWindowWidth,&mainWindowHeight);
+
+	fprintf(file,"%i %i %i %i %i\n",wantSaveSizePos, mainWindowX, mainWindowY, mainWindowWidth, mainWindowHeight);
+#endif
 	fclose(file);
 
 	/* Set Permissions to read/write only by user */
@@ -1476,7 +1521,7 @@ void resetButton(GtkWidget *widget,gpointer data)
 
         if(strcmp((char *)data,"Gamma") == 0)
         {
-                gtk_adjustment_set_value(GTK_ADJUSTMENT(gammaAdj),gamma);
+                gtk_adjustment_set_value(GTK_ADJUSTMENT(gammaAdj),ggamma);
                 return;
         }
 
@@ -1668,7 +1713,7 @@ void ShowWidgets(void)
                 gtk_main_iteration();
 
 	gtk_widget_queue_draw (GTK_WIDGET (mainWindow));
-	gtk_widget_show (mainWindow);
+	//gtk_widget_show (mainWindow);
 
 }
 
